


Welcome to WETB
===========================================

*- The Wind Energy Toolbox of DTU*

This toolbox provides Python tools intended for use in the wind
community, and especially HAWC2 users. Please see the Installation
tab on the left to install the code and get started.


Source code repository (and issue tracker):
    https://gitlab.windenergy.dtu.dk/toolbox/WindEnergyToolbox

License:
    GPLv3_

.. _GPLv3: https://gitlab.windenergy.dtu.dk/toolbox/WindEnergyToolbox/blob/master/LICENSE.txt


Contents:
    .. toctree::

        installation
        fatigue_tools/fatigue
        hawc2/hawc2
        bladed/bladed2hawc

